@@ -1,9 +1,8 @@
 # Link against mariadb native client static libraries
 # Info and source code: https://downloads.mariadb.org/client-native/
-# Source copy: http://rstats-db.github.io/RMySQL/mariadb_client-2.0.0-src.tar.gz
-if(!file.exists("../windows/libmariadbclient-2.3.2/include/mariadb/mysql.h")){
+if(!file.exists("../windows/libmariadbclient-2.3.4/include/mariadb/mysql.h")){
   if(getRversion() < "3.3.0") setInternet2()
-  download.file("https://github.com/rwinlib/libmariadbclient/archive/v2.3.2.zip", "lib.zip", quiet = TRUE)
+  curl::curl_download("https://github.com/rwinlib/libmariadbclient/archive/v2.3.4.zip", "lib.zip")
   dir.create("../windows", showWarnings = FALSE)
   unzip("lib.zip", exdir = "../windows")
   unlink("lib.zip")
